@@ -9,7 +9,7 @@ import glob
 import time
 
 
-__version__ = '0.0.4'
+__version__ = '0.0.9'
 
 samples_s3_folder = 'pypi_samples'
 inference_samples_s3_folder = 'pypi_toinfer'
@@ -44,53 +44,67 @@ class client():
                        
         
         
-    def train(self, path_to_positive_samples, path_to_negative_samples, confidence_threshold, n_pos = -1, n_neg = -1):
-               
+    def train(self, positive_samples, negative_samples, n_pos = -1, n_neg = -1):
+        
+        confidence_threshold = 0
+        
         config = utils.get_config('pypi')[0]
         event_manager_endpoint = config['event_manager_endpoint']
         aws_access_key = config['aws_access_key']
         aws_secret_key = config['aws_secret_key']
            
-        event_id = 'PP_' + ''.join(random.choices(string.ascii_uppercase + string.digits, k=9))
+        task_id = 'PP_' + ''.join(random.choices(string.ascii_uppercase + string.digits, k=9))
 
-        # Upload the positive samples into s3
-        positive_samples = glob.glob(path_to_positive_samples + "/*.jpg") + glob.glob(path_to_positive_samples + "/*.png") + glob.glob(path_to_positive_samples + "/*.JPG") + glob.glob(path_to_positive_samples + "/*.PNG") + glob.glob(path_to_positive_samples + "/*.JPEG") + glob.glob(path_to_positive_samples + "/*.bmt")
+        if isinstance(positive_samples, str):
+            # Upload the positive samples into s3
+            positive_samples = glob.glob(positive_samples + "/*.jpg") + glob.glob(positive_samples + "/*.png") + glob.glob(positive_samples + "/*.JPG") + glob.glob(positive_samples + "/*.PNG") + glob.glob(positive_samples + "/*.JPEG") + glob.glob(positive_samples + "/*.jpeg") + glob.glob(positive_samples + "/*.BMP") + glob.glob(positive_samples + "/*.bmp")
+        elif not isinstance(positive_samples, list):
+            raise Exception("Invalid first argument. positive_samples must be the path to the positive samples or a list of postive samples file names.")
         
         if n_pos > 0 and n_pos < len(positive_samples):
             positive_samples = positive_samples[:n_pos]
                 
+        print("Positive samples:")
         n_positive = 0
         for positive_sample in positive_samples:
             n_positive += 1
             utils.upload_to_s3(positive_sample,
                                samples_s3_folder, 
-                               "{}_positive_{}.jpg".format(event_id, str(n_positive)),
+                               "{}_positive_{}.jpg".format(task_id, str(n_positive)),
                                aws_access_key,
-                               aws_secret_key)        
+                               aws_secret_key) 
+            print("#{}: {}".format(str(n_positive), positive_sample))
         
-        print("Found {} positive samples.".format(str(n_positive)))
+        print("Found {} positive samples.\n".format(str(n_positive)))
         
-        # Upload the negative samples into s3
-        negative_samples = glob.glob(path_to_positive_samples + "/*.jpg") + glob.glob(path_to_positive_samples + "/*.png") + glob.glob(path_to_positive_samples + "/*.JPG") + glob.glob(path_to_positive_samples + "/*.PNG") + glob.glob(path_to_positive_samples + "/*.JPEG") + glob.glob(path_to_positive_samples + "/*.bmt")
+        if isinstance(negative_samples, str):
+            # Upload the negative samples into s3
+            negative_samples = glob.glob(negative_samples + "/*.jpg") + glob.glob(negative_samples + "/*.png") + glob.glob(negative_samples + "/*.JPG") + glob.glob(negative_samples + "/*.PNG") + glob.glob(negative_samples + "/*.JPEG") + glob.glob(negative_samples + "/*.jpeg") + glob.glob(negative_samples + "/*.BMP") + glob.glob(negative_samples + "/*.bmp")
+        elif not isinstance(negative_samples, list):
+            raise Exception("Invalid first argument. negative_samples must be the path to the negative samples or a list of negative samples file names.")
         
         if n_neg > 0 and n_neg < len(negative_samples):
             negative_samples = negative_samples[:n_neg]
         
+        print("Negative samples:")
         n_negative = 0
         for negative_sample in negative_samples:
             n_negative += 1
             utils.upload_to_s3(negative_sample, 
                                samples_s3_folder, 
-                               "{}_negative_{}.jpg".format(event_id, str(n_negative)),
+                               "{}_negative_{}.jpg".format(task_id, str(n_negative)),
                                aws_access_key,
                                aws_secret_key)
+            print("#{}: {}".format(str(n_negative), negative_sample))
         
-        print("Found {} negative samples.".format(str(n_negative)))
-        print("Creating the event... event_id = {}".format(event_id)) 
-        print("Training a model...")
+        print("Found {} negative samples.\n".format(str(n_negative)))
+        
+        print("Creating a task... task_id = {}\n".format(task_id)) 
+        
+        print("Training a model...\n")
         
         payload = {
-            "event_id": event_id,
+            "event_id": task_id,
             "camera_id": 'nil',
             "event_name": 'nil',
             "conf_threshold": confidence_threshold,
@@ -106,35 +120,42 @@ class client():
         
         resp_json = json.loads(resp.content)
         
-        return resp_json
+        result = {}
+        result['task_id'] = resp_json['event_id'] 
+        result['message'] = resp_json['message']
+        result['success'] = resp_json['success']
+        result['n_positive_samples'] = n_positive
+        result['n_negative_samples'] = n_negative
+        
+        return result
     
         
-    def predict(self, event_id, image_file):
+    def predict(self, task_id, image_file):
         
         config = utils.get_config('pypi')[0]
         event_predictor_endpoint =  config['event_predictor_endpoint']
         aws_access_key = config['aws_access_key']
         aws_secret_key = config['aws_secret_key']
         
-        events = utils.get_event(event_id)
-        conf_threshold = 0
-        if len(events) == 0:
-            return 'The event_id is invalid.'
-        elif len(events) > 1:
-            return 'Duplicate events in DB. Please contact VisualOne.'
-        else: 
-            conf_threshold = events[0]['conf_threshold']
+#         events = utils.get_event(event_id)
+#         conf_threshold = 0
+#         if len(events) == 0:
+#             return 'The event_id is invalid.'
+#         elif len(events) > 1:
+#             return 'Duplicate events in DB. Please contact VisualOne.'
+#         else: 
+#             conf_threshold = events[0]['conf_threshold']
             
         utils.upload_to_s3(image_file, 
                            inference_samples_s3_folder, 
-                           "{}.jpg".format(event_id),
+                           "{}.jpg".format(task_id),
                            aws_access_key,
                            aws_secret_key)
         
         payload = {
-            "event_id": event_id,
+            "event_id": task_id,
             "event_name": 'nil',
-            "image_name": "{}.jpg".format(event_id),
+            "image_name": "{}.jpg".format(task_id),
             "timestamp": round(time.time()*1000),
             "update_model": False,
             "force_late_infer": True,
@@ -152,9 +173,9 @@ class client():
             return 'An error occured.'
         
         result = {}
-        result['prediction'] = True if resp_json['confidence'] > conf_threshold else False
+        result['prediction'] = resp_json['prediction'] 
         result['confidence'] = resp_json['confidence']
-        result['event_id'] = resp_json['event_id']
+        result['task_id'] = resp_json['event_id']
         result['latency'] = resp_json['latency']
         
         return result
